==> chaosmesh-model-6.9.0-sources.jar: io/fabric8/chaosmesh/v1alpha1/StressInstanceFluent.java <==
package io.fabric8.chaosmesh.v1alpha1;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.String;

/**
 * Generated
 */
@SuppressWarnings("unchecked")
public class StressInstanceFluent<A extends StressInstanceFluent<A>> extends BaseFluent<A>{
  public StressInstanceFluent() {
  }
  
  public StressInstanceFluent(StressInstance instance) {
    this.copyInstance(instance);
  }
  private String memoryStartTime;
  private String memoryUid;
  private String startTime;
  private String uid;
  
  protected void copyInstance(StressInstance instance) {
    instance = (instance != null ? instance : new StressInstance());
  
    if (instance != null) {
        this.withMemoryStartTime(instance.getMemoryStartTime());
        this.withMemoryUid(instance.getMemoryUid());
        this.withStartTime(instance.getStartTime());
        this.withUid(instance.getUid());
        this.withMemoryStartTime(instance.getMemoryStartTime());
        this.withMemoryUid(instance.getMemoryUid());
        this.withStartTime(instance.getStartTime());
        this.withUid(instance.getUid());
      }
  }
  
  public String getMemoryStartTime() {
    return this.memoryStartTime;
  }
  
  public A withMemoryStartTime(String memoryStartTime) {
    this.memoryStartTime=memoryStartTime; return (A) this;
  }
  
  public boolean hasMemoryStartTime() {
    return this.memoryStartTime != null;
  }
  
  public String getMemoryUid() {
    return this.memoryUid;
  }
  
  public A withMemoryUid(String memoryUid) {
    this.memoryUid=memoryUid; return (A) this;
  }
  
  public boolean hasMemoryUid() {
    return this.memoryUid != null;
  }
  
  public String getStartTime() {
    return this.startTime;
  }
  
  public A withStartTime(String startTime) {
    this.startTime=startTime; return (A) this;
  }
  
  public boolean hasStartTime() {
    return this.startTime != null;
  }
  
  public String getUid() {
    return this.uid;
  }
  
  public A withUid(String uid) {
    this.uid=uid; return (A) this;
  }
  
  public boolean hasUid() {
    return this.uid != null;
  }
  
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    StressInstanceFluent that = (StressInstanceFluent) o;
    if (!java.util.Objects.equals(memoryStartTime, that.memoryStartTime)) return false;
  
    if (!java.util.Objects.equals(memoryUid, that.memoryUid)) return false;
  
    if (!java.util.Objects.equals(startTime, that.startTime)) return false;
  
    if (!java.util.Objects.equals(uid, that.uid)) return false;
  
    return true;
  }
  
  public int hashCode() {
    return java.util.Objects.hash(memoryStartTime,  memoryUid,  startTime,  uid,  super.hashCode());
  }
  
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (memoryStartTime != null) { sb.append("memoryStartTime:"); sb.append(memoryStartTime + ","); }
    if (memoryUid != null) { sb.append("memoryUid:"); sb.append(memoryUid + ","); }
    if (startTime != null) { sb.append("startTime:"); sb.append(startTime + ","); }
    if (uid != null) { sb.append("uid:"); sb.append(uid); }
    sb.append("}");
    return sb.toString();
  }
  

}

==> chaosmesh-model-6.9.1-sources.jar: io/fabric8/chaosmesh/v1alpha1/StressInstanceFluent.java <==
package io.fabric8.chaosmesh.v1alpha1;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.String;

/**
 * Generated
 */
@SuppressWarnings("unchecked")
public class StressInstanceFluent<A extends StressInstanceFluent<A>> extends BaseFluent<A>{
  public StressInstanceFluent() {
  }
  
  public StressInstanceFluent(StressInstance instance) {
    this.copyInstance(instance);
  }
  private String memoryStartTime;
  private String memoryUid;
  private String startTime;
  private String uid;
  
  protected void copyInstance(StressInstance instance) {
    instance = (instance != null ? instance : new StressInstance());
    if (instance != null) {
          this.withMemoryStartTime(instance.getMemoryStartTime());
          this.withMemoryUid(instance.getMemoryUid());
          this.withStartTime(instance.getStartTime());
          this.withUid(instance.getUid());
          this.withMemoryStartTime(instance.getMemoryStartTime());
          this.withMemoryUid(instance.getMemoryUid());
          this.withStartTime(instance.getStartTime());
          this.withUid(instance.getUid());
        }
  }
  
  public String getMemoryStartTime() {
    return this.memoryStartTime;
  }
  
  public A withMemoryStartTime(String memoryStartTime) {
    this.memoryStartTime = memoryStartTime;
    return (A) this;
  }
  
  public boolean hasMemoryStartTime() {
    return this.memoryStartTime != null;
  }
  
  public String getMemoryUid() {
    return this.memoryUid;
  }
  
  public A withMemoryUid(String memoryUid) {
    this.memoryUid = memoryUid;
    return (A) this;
  }
  
  public boolean hasMemoryUid() {
    return this.memoryUid != null;
  }
  
  public String getStartTime() {
    return this.startTime;
  }
  
  public A withStartTime(String startTime) {
    this.startTime = startTime;
    return (A) this;
  }
  
  public boolean hasStartTime() {
    return this.startTime != null;
  }
  
  public String getUid() {
    return this.uid;
  }
  
  public A withUid(String uid) {
    this.uid = uid;
    return (A) this;
  }
  
  public boolean hasUid() {
    return this.uid != null;
  }
  
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    StressInstanceFluent that = (StressInstanceFluent) o;
    if (!java.util.Objects.equals(memoryStartTime, that.memoryStartTime)) return false;
    if (!java.util.Objects.equals(memoryUid, that.memoryUid)) return false;
    if (!java.util.Objects.equals(startTime, that.startTime)) return false;
    if (!java.util.Objects.equals(uid, that.uid)) return false;
    return true;
  }
  
  public int hashCode() {
    return java.util.Objects.hash(memoryStartTime,  memoryUid,  startTime,  uid,  super.hashCode());
  }
  
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (memoryStartTime != null) { sb.append("memoryStartTime:"); sb.append(memoryStartTime + ","); }
    if (memoryUid != null) { sb.append("memoryUid:"); sb.append(memoryUid + ","); }
    if (startTime != null) { sb.append("startTime:"); sb.append(startTime + ","); }
    if (uid != null) { sb.append("uid:"); sb.append(uid); }
    sb.append("}");
    return sb.toString();
  }
  

}
